/*
 * Author: Blivervat 
 * createTime: 2017-09-01 10:38:40 
 * Last Modified by:   Blivervat 
 * Last Modified time: 2017-09-01 10:38:40 
 */
// 历史记录，支持不同画板不同历史。
// 通过canvas获取当前id，保存到不同的数组,有着不同的记录步数的index
let history = {}
let h = history


h.canvas = ''
h.readIndex = {}
h.readTemp = {}

h.id = ''
h.init = (canvas) => {
  h.canvas = canvas
  h.id = h.canvas.getElement().id
  h.readTemp[h.id] = h.readTemp[h.id] || []
  h.readIndex[h.id] = h.readIndex[h.id] || -1
  h.histemp = h.readTemp[h.id]
}
// 更新历史记录
h.update = (json) => {
  // 当撤销到其中一部，重新编辑时，应把这个步骤之后的数据全部删除，重新记录
  if (h.readIndex[h.id] !== h.histemp.length - 1) {
    h.histemp.splice(h.readIndex[h.id], h.histemp.length)
  }
  h.histemp.push(json)
  h.readIndex[h.id] = h.histemp.length - 1
  // 最多记录20步
  if (h.histemp.length > 20) {
    h.histemp.splice(0, h.histemp.length - 20)
  }
}
// 撤销
h.undo = () => {
  console.log(h.readIndex[h.id])
  if (h.readIndex[h.id] > 0) {
    h.readIndex[h.id] -= 1
    h.set()
  }
}
// 返回
h.redo = () => {
  console.log(h.readIndex[h.id])
  if (h.readIndex[h.id] < h.histemp.length) {
    h.readIndex[h.id] += 1
    h.set()
  }
}
// 触发更新数据，写成函数，方便监听事件
h.useUpdate = () => {
  if (this.historyTime) {
      clearTimeout(this.historyTime)
  }
  this.historyTime = setTimeout(() => {
      h.update(JSON.stringify(h.canvas.toJSON()))
  }, 300);
}
// 绑定监听，更新数据
h.useEvent = (canvas) => {
  canvas.on('object:modified', history.useUpdate)
  .on('object:added', history.useUpdate)
  .on('object:removed', history.useUpdate)
}
// 撤销绑定（撤销、返回也是更新数据，会触发监听，这不是我们想要的）
h.delEvent = (canvas) => {
  canvas.off('object:modified', history.useUpdate)
  .off('object:added', history.useUpdate)
  .off('object:removed', history.useUpdate)
}
// 加载返回、撤销数据
h.set = () => {
  h.delEvent(h.canvas)
  let json = h.histemp[h.readIndex[h.id]]
  json && h.canvas.loadFromJSON(json, () => {
    h.canvas.renderAll()
    h.useEvent(h.canvas)
  })
}

h.clear = () => {
  history.histemp = []
  h.readIndex[h.id] = -1
}

export default history
